{% load base_tags %}
{% load perm_tags %}

{% has_perm user video.change_video opt_object as can_edit %}
{% has_perm user video.delete_video opt_object as can_delete %}

<div class="t-iconrow">
	{% if can_edit %}
		<a class="option-link edit" href="{% url admin:videos_video_change opt_object.pk %}?next={{ request.path }}">Edit</a>
	{% endif %}
    {% if can_delete %}
        <a class="option-link delete" href="{% url admin:videos_video_delete opt_object.pk %}">Delete</a>
    {% endif %}
</div>